#[repr(align(16))]pub struct FieldElement([u8; 16]);Expand description
An element in POLYVAL’s field.
This type represents an element of the binary field GF(2^128) modulo the irreducible polynomial
x^128 + x^127 + x^126 + x^121 + 1 as described in RFC8452 3.
Arithmetic in POLYVAL’s field has the following properties:
- All arithmetic operations are performed modulo the polynomial above.
- Addition is equivalent to the XOR operation applied to the two field elements
- Multiplication is carryless
Tuple Fields
0: [u8; 16]Implementations
Sourceimpl FieldElement
impl FieldElement
Sourceimpl FieldElement
impl FieldElement
Sourcepub(crate) fn karatsuba_mul(self, rhs: Self) -> Product
pub(crate) fn karatsuba_mul(self, rhs: Self) -> Product
Compute the unreduced 256-bit carryless product of two 128-bit field elements.
Uses a Karatsuba decomposition in which the 128x128 multiplication is reduced to three 64x64 multiplications together with a bit-reversal trick to efficiently recover the high half.
Sourceimpl FieldElement
impl FieldElement
Sourcepub fn mulx(self) -> Self
pub fn mulx(self) -> Self
The mulX_POLYVAL() function as defined in RFC 8452 Appendix A.
Performs a doubling (a.k.a. “multiply by x”) over GF(2^128). This is useful for implementing GHASH in terms of POLYVAL.
Sourceimpl FieldElement
impl FieldElement